@@ -1,11 +1,12 @@
 """Tools for working with design spaces."""
-from typing import Any, List, Mapping, Type
+from typing import Any, List, Mapping, Type, Optional  # noqa
 from uuid import UUID
 
 from citrine._rest.resource import Resource
 from citrine._serialization import properties
 from citrine._serialization.serializable import Serializable
 from citrine._session import Session
+from citrine.informatics.data_sources import DataSource
 from citrine.informatics.descriptors import Descriptor
 from citrine.informatics.dimensions import Dimension
 from citrine.informatics.modules import Module
@@ -29,6 +30,7 @@ class DesignSpace(Module):
         return {
             'Univariate': ProductDesignSpace,
             'EnumeratedDesignSpace': EnumeratedDesignSpace,
+            'DataSourceDesignSpace': DataSourceDesignSpace
         }[data['config']['type']]
 
 
@@ -59,7 +61,7 @@ class ProductDesignSpace(Resource['ProductDesignSpace'], DesignSpace):
         'status_info',
         serializable=False
     )
-    active = properties.Boolean('active', default=True)
+    archived = properties.Boolean('archived', default=False)
     experimental = properties.Boolean("experimental", serializable=False, default=True)
     experimental_reasons = properties.Optional(
         properties.List(properties.String()),
@@ -124,7 +126,7 @@ class EnumeratedDesignSpace(Resource['EnumeratedDesignSpace'], DesignSpace):
         'status_info',
         serializable=False
     )
-    active = properties.Boolean('active', default=True)
+    archived = properties.Boolean('archived', default=False)
     experimental = properties.Boolean("experimental", serializable=False, default=True)
     experimental_reasons = properties.Optional(
         properties.List(properties.String()),
@@ -154,3 +156,61 @@ class EnumeratedDesignSpace(Resource['EnumeratedDesignSpace'], DesignSpace):
 
     def __str__(self):
         return '<EnumeratedDesignSpace {!r}>'.format(self.name)
+
+
+class DataSourceDesignSpace(Resource['DataSourceDesignSpace'], DesignSpace):
+    """[ALPHA] An enumeration of candidates stored in a data source.
+
+    Parameters
+    ----------
+    name:str
+        the name of the design space
+    description:str
+        the description of the design space
+    data_source: DataSource
+        the source of data for this design space
+
+    """
+
+    _response_key = None
+
+    uid = properties.Optional(properties.UUID, 'id', serializable=False)
+    name = properties.String('config.name')
+    description = properties.Optional(properties.String(), 'config.description')
+    data_source = properties.Object(DataSource, 'config.data_source')
+
+    typ = properties.String('config.type', default='DataSourceDesignSpace', deserializable=False)
+    status = properties.Optional(properties.String(), 'status', serializable=False)
+    status_info = properties.Optional(
+        properties.List(properties.String()),
+        'status_info',
+        serializable=False
+    )
+    archived = properties.Boolean('archived', default=False)
+    experimental = properties.Boolean("experimental", serializable=False, default=True)
+    experimental_reasons = properties.Optional(
+        properties.List(properties.String()),
+        'experimental_reasons',
+        serializable=False
+    )
+
+    # NOTE: These could go here or in _post_dump - it's unclear which is better right now
+    module_type = properties.String('module_type', default='DESIGN_SPACE', deserializable=False)
+    schema_id = properties.UUID('schema_id', default=UUID('f3907a58-aa46-462c-8837-a5aa9605e79e'),
+                                deserializable=False)
+
+    def __init__(self,
+                 name: str,
+                 description: str,
+                 data_source: DataSource):
+        self.name: str = name
+        self.description: str = description
+        self.data_source: DataSource = data_source
+        self.session: Optional[Session] = None
+
+    def _post_dump(self, data: dict) -> dict:
+        data['display_name'] = data['config']['name']
+        return data
+
+    def __str__(self):
+        return '<DataSourceDesignSpace {!r}>'.format(self.name)
