@@ -1,7 +1,8 @@
 """Tools for working with Predictors."""
 # flake8: noqa
-from typing import Dict, List, Optional, Type, Union
+from typing import List, Optional, Type, Union, Mapping
 from uuid import UUID
+from warnings import warn
 
 from citrine._serialization import properties as _properties
 from citrine._serialization.serializable import Serializable
@@ -9,11 +10,12 @@ from citrine._session import Session
 from citrine.informatics.data_sources import DataSource
 from citrine.informatics.descriptors import Descriptor, FormulationDescriptor, RealDescriptor, \
     MolecularStructureDescriptor
+from citrine.informatics.modules import Module
 from citrine.informatics.reports import Report
 from citrine.resources.report import ReportResource
-from citrine.informatics.modules import Module
 
-__all__ = ['ExpressionPredictor',
+__all__ = ['DeprecatedExpressionPredictor',
+           'ExpressionPredictor',
            'GraphPredictor',
            'IngredientsToSimpleMixturePredictor',
            'Predictor',
@@ -26,7 +28,7 @@ __all__ = ['ExpressionPredictor',
 
 
 class Predictor(Module):
-    """[ALPHA] Module that describes the ability to compute/predict properties of materials.
+    """Module that describes the ability to compute/predict properties of materials.
 
     Abstract type that returns the proper type given a serialized dict. subtype
     based on the 'type' value of the passed in dict.
@@ -34,6 +36,24 @@ class Predictor(Module):
     """
 
     _response_key = None
+    uid = _properties.Optional(_properties.UUID, 'id', serializable=False)
+    """UUID of the predictor, if it has been retrieved from the platform."""
+
+    name = _properties.String('config.name')
+    description = _properties.Optional(_properties.String(), 'config.description')
+    status = _properties.Optional(_properties.String(), 'status', serializable=False)
+    status_info = _properties.Optional(
+        _properties.List(_properties.String()),
+        'status_info',
+        serializable=False
+    )
+    archived = _properties.Boolean('archived', default=False)
+    experimental = _properties.Boolean("experimental", serializable=False, default=True)
+    experimental_reasons = _properties.Optional(
+        _properties.List(_properties.String()),
+        'experimental_reasons',
+        serializable=False
+    )
 
     def post_build(self, project_id: UUID, data: dict):
         """Executes after a .build() is called in [[PredictorCollection]]."""
@@ -45,7 +65,8 @@ class Predictor(Module):
         type_dict = {
             "Simple": SimpleMLPredictor,
             "Graph": GraphPredictor,
-            "Expression": ExpressionPredictor,
+            "Expression": DeprecatedExpressionPredictor,
+            "AnalyticExpression": ExpressionPredictor,
             "MoleculeFeaturizer": MolecularStructureFeaturizer,
             "IngredientsToSimpleMixture": IngredientsToSimpleMixturePredictor,
             "GeneralizedMeanProperty": GeneralizedMeanPropertyPredictor,
@@ -63,9 +84,31 @@ class Predictor(Module):
                 'Must be in {}.'.format(data['config']['type'], type_dict.keys())
             )
 
+    def _wrap_training_data(self, training_data: Optional[Union[DataSource, List[DataSource]]]) -> List[DataSource]:
+        """
+        Converts ``None`` to an empty list and wraps a single data source in a list that contains a single element.
+
+        Parameters
+        ----------
+        training_data: Optional[Union[DataSource, List[DataSource]]]
+            Either a single data source, list of data sources or ``None``
+        Returns
+        -------
+        List[DataSource]
+            A list of data sources
+        """
+        if training_data is None:
+            return []
+        if isinstance(training_data, DataSource):
+            warn("Specifying training data as a single data source is deprecated. "
+                 "Please use a list of data sources to create {} instead.".format(self),
+                 DeprecationWarning)
+            return [training_data]
+        return training_data
+
 
 class SimpleMLPredictor(Serializable['SimplePredictor'], Predictor):
-    """[ALPHA] A predictor interface that builds a simple graphical model.
+    """A predictor interface that builds a simple graphical model.
 
     The model connects the set of inputs through latent variables to the outputs.
     Supported complex inputs (such as chemical formulas) are auto-featurized and machine learning
@@ -83,32 +126,21 @@ class SimpleMLPredictor(Serializable['SimplePredictor'], Predictor):
         Descriptors that represent outputs of relations
     latent_variables: list[Descriptor]
         Descriptors that are predicted from inputs and used when predicting the outputs
-    training_data: DataSource
-        Source of the training data, which can be either a CSV or an Ara table
+    training_data: Optional[List[DataSource]]
+        Sources of training data. Each can be either a CSV or an GEM Table.
+        Candidates from multiple data sources will be combined into a flattened list and deduplicated by uid
+        and identifiers. Deduplication is performed if a uid or identifier is shared between two or more rows.
+        The content of a deduplicated row will contain the union of data across all rows that share the same uid
+        or at least 1 identifier. Training data is optional if the predictor is part of a graph that includes
+        all training data required by this predictor.
 
     """
 
-    uid = _properties.Optional(_properties.UUID, 'id', serializable=False)
-    name = _properties.String('config.name')
-    description = _properties.Optional(_properties.String(), 'config.description')
     inputs = _properties.List(_properties.Object(Descriptor), 'config.inputs')
     outputs = _properties.List(_properties.Object(Descriptor), 'config.outputs')
     latent_variables = _properties.List(_properties.Object(Descriptor), 'config.latent_variables')
-    training_data = _properties.Object(DataSource, 'config.training_data')
+    training_data = _properties.List(_properties.Object(DataSource), 'config.training_data')
     typ = _properties.String('config.type', default='Simple', deserializable=False)
-    status = _properties.Optional(_properties.String(), 'status', serializable=False)
-    status_info = _properties.Optional(
-        _properties.List(_properties.String()),
-        'status_info',
-        serializable=False
-    )
-    active = _properties.Boolean('active', default=True)
-    experimental = _properties.Boolean("experimental", serializable=False, default=True)
-    experimental_reasons = _properties.Optional(
-        _properties.List(_properties.String()),
-        'experimental_reasons',
-        serializable=False
-    )
 
     # NOTE: These could go here or in _post_dump - it's unclear which is better right now
     module_type = _properties.String('module_type', default='PREDICTOR')
@@ -120,19 +152,19 @@ class SimpleMLPredictor(Serializable['SimplePredictor'], Predictor):
                  inputs: List[Descriptor],
                  outputs: List[Descriptor],
                  latent_variables: List[Descriptor],
-                 training_data: DataSource,
+                 training_data: Optional[List[DataSource]] = None,
                  session: Optional[Session] = None,
                  report: Optional[Report] = None,
-                 active: bool = True):
+                 archived: bool = False):
         self.name: str = name
         self.description: str = description
         self.inputs: List[Descriptor] = inputs
         self.outputs: List[Descriptor] = outputs
         self.latent_variables: List[Descriptor] = latent_variables
-        self.training_data: DataSource = training_data
+        self.training_data: List[DataSource] = self._wrap_training_data(training_data)
         self.session: Optional[Session] = session
         self.report: Optional[Report] = report
-        self.active: bool = active
+        self.archived: bool = archived
 
     def _post_dump(self, data: dict) -> dict:
         data['display_name'] = data['config']['name']
@@ -143,7 +175,7 @@ class SimpleMLPredictor(Serializable['SimplePredictor'], Predictor):
 
 
 class GraphPredictor(Serializable['GraphPredictor'], Predictor):
-    """[ALPHA] A predictor interface that stitches other predictors together.
+    """A predictor interface that stitches other predictors together.
 
     Parameters
     ----------
@@ -151,32 +183,25 @@ class GraphPredictor(Serializable['GraphPredictor'], Predictor):
         name of the configuration
     description: str
         the description of the predictor
-    predictors: list[UUID, Predictor]
+    predictors: List[Union[UUID, Predictor]]
         the list of predictors to use in the grpah, either UUIDs or serialized predictors
+    training_data: Optional[List[DataSource]]
+        Optional sources of training data shared by all predictors in the graph.
+        Training data provided by this graph predictor does not need to be specified as part of the
+        configuration of sub-predictors. Shared training data and any training data specified by a sub-predictor
+        will be combined into a flattened list and deduplicated by uid and identifiers. Deduplication is performed
+        if a uid or identifier is shared between two or more rows. The content of a deduplicated row will contain
+        the union of data across all rows that share the same uid or at least 1 identifier.
 
     """
 
-    uid = _properties.Optional(_properties.UUID, 'id', serializable=False)
-    name = _properties.String('config.name')
-    description = _properties.String('config.description')
     predictors = _properties.List(_properties.Union(
         [_properties.UUID, _properties.Object(Predictor)]), 'config.predictors')
+    training_data = _properties.List(_properties.Object(DataSource), 'config.training_data')
     typ = _properties.String('config.type', default='Graph', deserializable=False)
     # Graph predictors may not be embedded in other predictors, hence while status is optional
     # for deserializing most predictors, it is required for deserializing a graph
     status = _properties.String('status', serializable=False)
-    status_info = _properties.Optional(
-        _properties.List(_properties.String()),
-        'status_info',
-        serializable=False
-    )
-    experimental = _properties.Boolean("experimental", serializable=False, default=True)
-    experimental_reasons = _properties.Optional(
-        _properties.List(_properties.String()),
-        'experimental_reasons',
-        serializable=False
-    )
-    active = _properties.Boolean('active', default=True)
 
     # NOTE: These could go here or in _post_dump - it's unclear which is better right now
     module_type = _properties.String('module_type', default='PREDICTOR')
@@ -186,15 +211,17 @@ class GraphPredictor(Serializable['GraphPredictor'], Predictor):
                  name: str,
                  description: str,
                  predictors: List[Union[UUID, Predictor]],
+                 training_data: Optional[List[DataSource]] = None,
                  session: Optional[Session] = None,
                  report: Optional[Report] = None,
-                 active: bool = True):
+                 archived: bool = False):
         self.name: str = name
         self.description: str = description
         self.predictors: List[Union[UUID, Predictor]] = predictors
+        self.training_data: List[DataSource] = self._wrap_training_data(training_data)
         self.session: Optional[Session] = session
         self.report: Optional[Report] = report
-        self.active: bool = active
+        self.archived: bool = archived
 
     def _post_dump(self, data: dict) -> dict:
         data['display_name'] = data['config']['name']
@@ -218,7 +245,7 @@ class GraphPredictor(Serializable['GraphPredictor'], Predictor):
         return dict(
             module_type='PREDICTOR',
             config=predictor,
-            active=False,
+            archived=False,
             schema_id='43c61ad4-7e33-45d0-a3de-504acb4e0737'  # TODO: what should this be?
         )
 
@@ -226,8 +253,63 @@ class GraphPredictor(Serializable['GraphPredictor'], Predictor):
         return '<GraphPredictor {!r}>'.format(self.name)
 
 
-class ExpressionPredictor(Serializable['ExpressionPredictor'], Predictor):
-    """[ALPHA] A predictor interface that allows calculator expressions.
+class DeprecatedExpressionPredictor(Serializable['DeprecatedExpressionPredictor'], Predictor):
+    """[DEPRECATED] A predictor that computes an output from an analytic expression.
+
+    This predictor is deprecated. Please use the :class:`~citrine.informatics.predictors.ExpressionPredictor` instead.
+    To migrate to the new predictor:
+
+    1. add an alias for all unknown expression arguments and
+    2. replace descriptor keys in ``aliases`` with the associated descriptor
+
+    These changes allow the expression to respect descriptor bounds when computing the output and avoid potential
+    descriptor mismatches if a descriptor with an identical key and different bounds is present in the graph.
+
+    The following example shows how to migrate a deprecated expression predictor to the new format.
+    In the deprecated format, an expression that computes shear modulus from Young's modulus and Poisson's ratio is given by:
+
+    .. code-block:: python
+
+       from citrine.informatics.predictors import DeprecatedExpressionPredictor
+
+       shear_modulus = RealDescriptor('Property~Shear modulus', lower_bound=0, upper_bound=100, units='GPa')
+
+       shear_modulus_predictor = DeprecatedExpressionPredictor(
+           name = 'Shear modulus predictor',
+           description = "Computes shear modulus from Young's modulus and Poisson's ratio.",
+           expression = 'Y / (2 * (1 + v))',
+           output = shear_modulus,
+           aliases = {
+               'Y': "Young's modulus",
+               'v': "Poisson's ratio"
+           }
+       )
+
+    To create a predictor using the format, we need to create descriptors for the expression inputs: Young's modulus and Poisson's ratio.
+    We also need to replace references to the descriptor keys in ``aliases`` with the new descriptors:
+
+    .. code-block:: python
+
+       from citrine.informatics.predictors import ExpressionPredictor
+
+       # create a descriptor for each input in addition to the output
+       youngs_modulus = RealDescriptor('Property~Young\'s modulus', lower_bound=0, upper_bound=100, units='GPa')
+       poissons_ratio = RealDescriptor('Property~Poisson\'s ratio', lower_bound=-1, upper_bound=0.5, units='')
+       shear_modulus = RealDescriptor('Property~Shear modulus', lower_bound=0, upper_bound=100, units='GPa')
+
+       shear_modulus_predictor = ExpressionPredictor(
+           name = 'Shear modulus predictor',
+           description = "Computes shear modulus from Young's modulus and Poisson's ratio.",
+           expression = 'Y / (2 * (1 + v))',
+           output = shear_modulus,
+           # note, arguments map to descriptors not descriptor keys
+           aliases = {
+               'Y': youngs_modulus,
+               'v': poissons_ratio
+           }
+       )
+
+    .. seealso:: :class:`~citrine.informatics.predictors.ExpressionPredictor`
 
     Parameters
     ----------
@@ -236,35 +318,19 @@ class ExpressionPredictor(Serializable['ExpressionPredictor'], Predictor):
     description: str
         the description of the predictor
     expression: str
-        the expression that uses the aliased values
-    output: Descriptor
-        the Descriptor that represents the output relation
-    aliases: dict
-        a mapping from expression argument to descriptor key
+        expression that computes an output from a set of inputs
+    output: RealDescriptor
+        descriptor that represents the output of the expression
+    aliases: Optional[Mapping[str, str]]
+        a mapping from each each argument as it appears in the ``expression`` to its descriptor key.
+        If an unknown argument is not aliased, the argument and descriptor key are assumed to be identical.
 
     """
 
-    uid = _properties.Optional(_properties.UUID, 'id', serializable=False)
-    name = _properties.String('config.name')
-    description = _properties.String('config.description')
     expression = _properties.String('config.expression')
-    output = _properties.Object(Descriptor, 'config.output')
-    aliases = _properties.Mapping(_properties.String, _properties.String, 'config.aliases')
+    output = _properties.Object(RealDescriptor, 'config.output')
+    aliases = _properties.Optional(_properties.Mapping(_properties.String, _properties.String), 'config.aliases')
     typ = _properties.String('config.type', default='Expression', deserializable=False)
-    status = _properties.Optional(_properties.String(), 'status', serializable=False)
-    status_info = _properties.Optional(
-        _properties.List(_properties.String()),
-        'status_info',
-        serializable=False
-    )
-    experimental = _properties.Boolean("experimental", serializable=False, default=True)
-    experimental_reasons = _properties.Optional(
-        _properties.List(_properties.String()),
-        'experimental_reasons',
-        serializable=False
-    )
-
-    active = _properties.Boolean('active', default=True)
 
     # NOTE: These could go here or in _post_dump - it's unclear which is better right now
     module_type = _properties.String('module_type', default='PREDICTOR')
@@ -274,19 +340,80 @@ class ExpressionPredictor(Serializable['ExpressionPredictor'], Predictor):
                  name: str,
                  description: str,
                  expression: str,
-                 output: Descriptor,
-                 aliases: dict,
+                 output: RealDescriptor,
+                 aliases: Optional[Mapping[str, str]] = None,
                  session: Optional[Session] = None,
                  report: Optional[Report] = None,
-                 active: bool = True):
+                 archived: bool = False):
+        warn("{this_class} is deprecated. Please use {replacement} instead"
+             .format(this_class=self.__class__.name, replacement=ExpressionPredictor.__name__))
+        self.name: str = name
+        self.description: str = description
+        self.expression: str = expression
+        self.output: RealDescriptor = output
+        self.aliases: Optional[Mapping[str, str]] = aliases
+        self.session: Optional[Session] = session
+        self.report: Optional[Report] = report
+        self.archived: bool = archived
+
+    def _post_dump(self, data: dict) -> dict:
+        data['display_name'] = data['config']['name']
+        return data
+
+    def __str__(self):
+        return '<DeprecatedExpressionPredictor {!r}>'.format(self.name)
+
+
+class ExpressionPredictor(Serializable['ExpressionPredictor'], Predictor):
+    """A predictor that computes an output from an expression and set of bounded inputs.
+
+    .. seealso::
+       If you are using the deprecated predictor please see
+       :class:`~citrine.informatics.predictors.DeprecatedExpressionPredictor` for an example that shows how to migrate
+       to the new format.
+
+    Parameters
+    ----------
+    name: str
+        name of the configuration
+    description: str
+        the description of the predictor
+    expression: str
+        expression that computes an output from aliased inputs
+    output: RealDescriptor
+        descriptor that represents the output relation
+    aliases: Mapping[str, RealDescriptor]
+        a mapping from each unknown argument to its descriptor.
+        All unknown arguments must have an associated descriptor.
+
+    """
+
+    expression = _properties.String('config.expression')
+    output = _properties.Object(RealDescriptor, 'config.output')
+    aliases = _properties.Mapping(_properties.String, _properties.Object(RealDescriptor), 'config.aliases')
+    typ = _properties.String('config.type', default='AnalyticExpression', deserializable=False)
+
+    # NOTE: These could go here or in _post_dump - it's unclear which is better right now
+    module_type = _properties.String('module_type', default='PREDICTOR')
+    schema_id = _properties.UUID('schema_id', default=UUID('f1601161-bb98-4fa9-bdd2-a2a673547532'))
+
+    def __init__(self,
+                 name: str,
+                 description: str,
+                 expression: str,
+                 output: RealDescriptor,
+                 aliases: Mapping[str, RealDescriptor],
+                 session: Optional[Session] = None,
+                 report: Optional[Report] = None,
+                 archived: bool = False):
         self.name: str = name
         self.description: str = description
         self.expression: str = expression
         self.output: Descriptor = output
-        self.aliases: dict = aliases
+        self.aliases: Mapping[str, RealDescriptor] = aliases
         self.session: Optional[Session] = session
         self.report: Optional[Report] = report
-        self.active: bool = active
+        self.archived: bool = archived
 
     def _post_dump(self, data: dict) -> dict:
         data['display_name'] = data['config']['name']
@@ -359,26 +486,10 @@ class MolecularStructureFeaturizer(Serializable['MolecularStructureFeaturizer'],
 
     """
 
-    uid = _properties.Optional(_properties.UUID, 'id', serializable=False)
-    name = _properties.String('config.name')
-    description = _properties.String('config.description')
     descriptor = _properties.Object(Descriptor, 'config.descriptor')
     features = _properties.List(_properties.String, 'config.features')
     excludes = _properties.List(_properties.String, 'config.excludes')
     typ = _properties.String('config.type', default='MoleculeFeaturizer', deserializable=False)
-    status = _properties.Optional(_properties.String, 'status', serializable=False)
-    status_info = _properties.Optional(
-        _properties.List(_properties.String),
-        'status_info',
-        serializable=False
-    )
-    active = _properties.Boolean('active', default=True)
-    experimental = _properties.Boolean("experimental", serializable=False, default=True)
-    experimental_reasons = _properties.Optional(
-        _properties.List(_properties.String()),
-        'experimental_reasons',
-        serializable=False
-    )
 
     # NOTE: These could go here or in _post_dump - it's unclear which is better right now
     module_type = _properties.String('module_type', default='PREDICTOR')
@@ -392,7 +503,7 @@ class MolecularStructureFeaturizer(Serializable['MolecularStructureFeaturizer'],
                  excludes: List[str] = None,
                  session: Optional[Session] = None,
                  report: Optional[Report] = None,
-                 active: bool = True):
+                 archived: bool = False):
         self.name: str = name
         self.description: str = description
         self.descriptor = descriptor
@@ -400,7 +511,7 @@ class MolecularStructureFeaturizer(Serializable['MolecularStructureFeaturizer'],
         self.excludes = excludes if excludes is not None else []
         self.session: Optional[Session] = session
         self.report: Optional[Report] = report
-        self.active: bool = active
+        self.archived: bool = archived
 
     def _post_dump(self, data: dict) -> dict:
         data['display_name'] = data['config']['name']
@@ -422,18 +533,15 @@ class IngredientsToSimpleMixturePredictor(
         description of the predictor
     output: FormulationDescriptor
         descriptor that represents the output formulation
-    id_to_quantity: Dict[str, RealDescriptor]
+    id_to_quantity: Mapping[str, RealDescriptor]
         Map from ingredient identifier to the descriptor that represents its quantity,
         e.g. ``{'water': RealDescriptor('water quantity', 0, 1)}``
-    labels: Dict[str, List[str]]
+    labels: Mapping[str, List[str]]
         Map from each label to all ingredients assigned that label, when present in a mixture,
         e.g. ``{'solvent': ['water']}``
 
     """
 
-    uid = _properties.Optional(_properties.UUID, 'id', serializable=False)
-    name = _properties.String('config.name')
-    description = _properties.String('config.description')
     output = _properties.Object(FormulationDescriptor, 'config.output')
     id_to_quantity = _properties.Mapping(_properties.String, _properties.Object(RealDescriptor),
                                          'config.id_to_quantity')
@@ -441,19 +549,6 @@ class IngredientsToSimpleMixturePredictor(
                                  'config.labels')
     typ = _properties.String('config.type', default='IngredientsToSimpleMixture',
                              deserializable=False)
-    status = _properties.Optional(_properties.String(), 'status', serializable=False)
-    status_info = _properties.Optional(
-        _properties.List(_properties.String()),
-        'status_info',
-        serializable=False
-    )
-    active = _properties.Boolean('active', default=True)
-    experimental = _properties.Boolean("experimental", serializable=False, default=True)
-    experimental_reasons = _properties.Optional(
-        _properties.List(_properties.String()),
-        'experimental_reasons',
-        serializable=False
-    )
 
     # NOTE: These could go here or in _post_dump - it's unclear which is better right now
     module_type = _properties.String('module_type', default='PREDICTOR')
@@ -463,19 +558,19 @@ class IngredientsToSimpleMixturePredictor(
                  name: str,
                  description: str,
                  output: FormulationDescriptor,
-                 id_to_quantity: Dict[str, RealDescriptor],
-                 labels: Dict[str, List[str]],
+                 id_to_quantity: Mapping[str, RealDescriptor],
+                 labels: Mapping[str, List[str]],
                  session: Optional[Session] = None,
                  report: Optional[Report] = None,
-                 active: bool = True):
+                 archived: bool = False):
         self.name: str = name
         self.description: str = description
         self.output: FormulationDescriptor = output
-        self.id_to_quantity: Dict[str, RealDescriptor] = id_to_quantity
-        self.labels: Dict[str, List[str]] = labels
+        self.id_to_quantity: Mapping[str, RealDescriptor] = id_to_quantity
+        self.labels: Mapping[str, List[str]] = labels
         self.session: Optional[Session] = session
         self.report: Optional[Report] = report
-        self.active: bool = active
+        self.archived: bool = archived
 
     def _post_dump(self, data: dict) -> dict:
         data['display_name'] = data['config']['name']
@@ -508,11 +603,16 @@ class GeneralizedMeanPropertyPredictor(
         entire dataset is used.
         If ``True`` and a default is specified in ``default_properties``, then the specified
         default is used in place of missing values.
-    training_data: DataSource
-        Source of the training data, which can be either a CSV or an Ara table
     label: Optional[str]
         Optional label
-    default_properties: Optional[Dict[str, float]]
+    training_data: Optional[List[DataSource]]
+        Sources of training data. Each can be either a CSV or an GEM Table.
+        Candidates from multiple data sources will be combined into a flattened list and deduplicated by uid
+        and identifiers. Deduplication is performed if a uid or identifier is shared between two or more rows.
+        The content of a deduplicated row will contain the union of data across all rows that share the same uid
+        or at least 1 identifier. Training data is optional if the predictor is part of a graph that includes
+        all training data required by this predictor.
+    default_properties: Optional[Mapping[str, float]]
         Default values to use for imputed properties.
         Defaults are specified as a map from descriptor key to its default value.
         If not specified and ``impute_properties == True`` the average over the entire dataset
@@ -522,32 +622,16 @@ class GeneralizedMeanPropertyPredictor(
 
     """
 
-    uid = _properties.Optional(_properties.UUID, 'id', serializable=False)
-    name = _properties.String('config.name')
-    description = _properties.String('config.description')
     input_descriptor = _properties.Object(FormulationDescriptor, 'config.input')
     properties = _properties.List(_properties.String, 'config.properties')
     p = _properties.Float('config.p')
-    training_data = _properties.Object(DataSource, 'config.training_data')
+    training_data = _properties.List(_properties.Object(DataSource), 'config.training_data')
     impute_properties = _properties.Boolean('config.impute_properties')
     default_properties = _properties.Optional(
         _properties.Mapping(_properties.String, _properties.Float), 'config.default_properties')
     label = _properties.Optional(_properties.String, 'config.label')
     typ = _properties.String('config.type', default='GeneralizedMeanProperty',
                              deserializable=False)
-    status = _properties.Optional(_properties.String, 'status', serializable=False)
-    status_info = _properties.Optional(
-        _properties.List(_properties.String),
-        'status_info',
-        serializable=False
-    )
-    active = _properties.Boolean('active', default=True)
-    experimental = _properties.Boolean("experimental", serializable=False, default=True)
-    experimental_reasons = _properties.Optional(
-        _properties.List(_properties.String()),
-        'experimental_reasons',
-        serializable=False
-    )
 
     # NOTE: These could go here or in _post_dump - it's unclear which is better right now
     module_type = _properties.String('module_type', default='PREDICTOR')
@@ -559,25 +643,25 @@ class GeneralizedMeanPropertyPredictor(
                  input_descriptor: FormulationDescriptor,
                  properties: List[str],
                  p: float,
-                 training_data: DataSource,
                  impute_properties: bool,
-                 default_properties: Optional[Dict[str, float]] = None,
+                 default_properties: Optional[Mapping[str, float]] = None,
                  label: Optional[str] = None,
+                 training_data: Optional[List[DataSource]] = None,
                  session: Optional[Session] = None,
                  report: Optional[Report] = None,
-                 active: bool = True):
+                 archived: bool = False):
         self.name: str = name
         self.description: str = description
         self.input_descriptor: FormulationDescriptor = input_descriptor
         self.properties: List[str] = properties
         self.p: float = p
-        self.training_data = training_data
+        self.training_data: List[DataSource] = self._wrap_training_data(training_data)
         self.impute_properties: bool = impute_properties
-        self.default_properties: Optional[Dict[str, float]] = default_properties
+        self.default_properties: Optional[Mapping[str, float]] = default_properties
         self.label: Optional[str] = label
         self.session: Optional[Session] = session
         self.report: Optional[Report] = report
-        self.active: bool = active
+        self.archived: bool = archived
 
     def _post_dump(self, data: dict) -> dict:
         data['display_name'] = data['config']['name']
@@ -601,30 +685,21 @@ class SimpleMixturePredictor(Serializable['SimpleMixturePredictor'], Predictor):
         input descriptor for the hierarchical (un-mixed) formulation
     output_descriptor: FormulationDescriptor
         output descriptor for the flat (mixed) formulation
-    training_data: DataSource
-        Source of the training data, which can be either a CSV or an Ara table
+    training_data: Optional[List[DataSource]]
+        Sources of training data. Each can be either a CSV or an GEM Table.
+        Candidates from multiple data sources will be combined into a flattened list and deduplicated by uid
+        and identifiers. Deduplication is performed if a uid or identifier is shared between two or more rows.
+        The content of a deduplicated row will contain the union of data across all rows that share the same uid
+        or at least 1 identifier. Training data is optional if the predictor is part of a graph that includes
+        all training data required by this predictor.
 
     """
 
-    uid = _properties.Optional(_properties.UUID, 'id', serializable=False)
-    name = _properties.String('config.name')
-    description = _properties.String('config.description')
     input_descriptor = _properties.Object(FormulationDescriptor, 'config.input')
     output_descriptor = _properties.Object(FormulationDescriptor, 'config.output')
-    training_data = _properties.Object(DataSource, 'config.training_data')
+    training_data = _properties.List(_properties.Object(DataSource), 'config.training_data')
     typ = _properties.String('config.type', default='SimpleMixture',
                              deserializable=False)
-    status = _properties.Optional(_properties.String, 'status', serializable=False)
-    status_info = _properties.Optional(_properties.List(_properties.String),
-                                       'status_info',
-                                       serializable=False)
-    active = _properties.Boolean('active', default=True)
-    experimental = _properties.Boolean("experimental", serializable=False, default=True)
-    experimental_reasons = _properties.Optional(
-        _properties.List(_properties.String()),
-        'experimental_reasons',
-        serializable=False
-    )
 
     # NOTE: These could go here or in _post_dump - it's unclear which is better right now
     module_type = _properties.String('module_type', default='PREDICTOR')
@@ -635,18 +710,18 @@ class SimpleMixturePredictor(Serializable['SimpleMixturePredictor'], Predictor):
                  description: str,
                  input_descriptor: FormulationDescriptor,
                  output_descriptor: FormulationDescriptor,
-                 training_data: DataSource,
+                 training_data: Optional[List[DataSource]] = None,
                  session: Optional[Session] = None,
                  report: Optional[Report] = None,
-                 active: bool = True):
+                 archived: bool = False):
         self.name: str = name
         self.description: str = description
         self.input_descriptor: FormulationDescriptor = input_descriptor
         self.output_descriptor: FormulationDescriptor = output_descriptor
-        self.training_data = training_data
+        self.training_data: List[DataSource] = self._wrap_training_data(training_data)
         self.session: Optional[Session] = session
         self.report: Optional[Report] = report
-        self.active: bool = active
+        self.archived: bool = archived
 
     def _post_dump(self, data: dict) -> dict:
         data['display_name'] = data['config']['name']
@@ -672,26 +747,10 @@ class LabelFractionsPredictor(Serializable['LabelFractionsPredictor'], Predictor
 
     """
 
-    uid = _properties.Optional(_properties.UUID, 'id', serializable=False)
-    name = _properties.String('config.name')
-    description = _properties.String('config.description')
     input_descriptor = _properties.Object(FormulationDescriptor, 'config.input')
     labels = _properties.List(_properties.String, 'config.labels')
     typ = _properties.String('config.type', default='LabelFractions',
                              deserializable=False)
-    status = _properties.Optional(_properties.String, 'status', serializable=False)
-    status_info = _properties.Optional(
-        _properties.List(_properties.String),
-        'status_info',
-        serializable=False
-    )
-    active = _properties.Boolean('active', default=True)
-    experimental = _properties.Boolean("experimental", serializable=False, default=True)
-    experimental_reasons = _properties.Optional(
-        _properties.List(_properties.String()),
-        'experimental_reasons',
-        serializable=False
-    )
 
     # NOTE: These could go here or in _post_dump - it's unclear which is better right now
     module_type = _properties.String('module_type', default='PREDICTOR')
@@ -704,14 +763,14 @@ class LabelFractionsPredictor(Serializable['LabelFractionsPredictor'], Predictor
                  labels: List[str],
                  session: Optional[Session] = None,
                  report: Optional[Report] = None,
-                 active: bool = True):
+                 archived: bool = False):
         self.name: str = name
         self.description: str = description
         self.input_descriptor: FormulationDescriptor = input_descriptor
         self.labels: List[str] = labels
         self.session: Optional[Session] = session
         self.report: Optional[Report] = report
-        self.active: bool = active
+        self.archived: bool = archived
 
     def _post_dump(self, data: dict) -> dict:
         data['display_name'] = data['config']['name']
@@ -737,9 +796,6 @@ class IngredientFractionsPredictor(Serializable["IngredientFractionsPredictor"],
         This list should contain all possible ingredients.
         If an unknown ingredient is encountered, an error will be thrown.
     """
-    uid = _properties.Optional(_properties.UUID, 'id', serializable=False)
-    name = _properties.String('config.name')
-    description = _properties.String('config.description')
     input_descriptor = _properties.Object(FormulationDescriptor, 'config.input')
     ingredients = _properties.List(_properties.String, 'config.ingredients')
 
@@ -748,19 +804,6 @@ class IngredientFractionsPredictor(Serializable["IngredientFractionsPredictor"],
     schema_id = _properties.UUID('schema_id', default=UUID('eb02a095-8cdc-45d8-bc82-1013b6e8e700'))
     typ = _properties.String('config.type', default='IngredientFractions',
                              deserializable=False)
-    status = _properties.Optional(_properties.String, 'status', serializable=False)
-    status_info = _properties.Optional(
-        _properties.List(_properties.String),
-        'status_info',
-        serializable=False
-    )
-    active = _properties.Boolean('active', default=True)
-    experimental = _properties.Boolean("experimental", serializable=False, default=True)
-    experimental_reasons = _properties.Optional(
-        _properties.List(_properties.String()),
-        'experimental_reasons',
-        serializable=False
-    )
 
     def __init__(self,
                  name: str,
@@ -769,14 +812,14 @@ class IngredientFractionsPredictor(Serializable["IngredientFractionsPredictor"],
                  ingredients: List[str],
                  session: Optional[Session] = None,
                  report: Optional[Report] = None,
-                 active: bool = True):
+                 archived: bool = False):
         self.name: str = name
         self.description: str = description
         self.input_descriptor: FormulationDescriptor = input_descriptor
         self.ingredients: List[str] = ingredients
         self.session: Optional[Session] = session
         self.report: Optional[Report] = report
-        self.active: bool = active
+        self.archived: bool = archived
 
     def _post_dump(self, data: dict) -> dict:
         data['display_name'] = data['config']['name']
