@@ -10,7 +10,7 @@ CreationType = TypeVar('CreationType', bound=Processor)
 
 
 class ProcessorCollection(Collection[Processor]):
-    """Represents the collection of all processors for a project.
+    """[ALPHA] Represents the collection of all processors for a project.
 
     Parameters
     ----------
@@ -21,6 +21,8 @@ class ProcessorCollection(Collection[Processor]):
 
     _path_template = '/projects/{project_id}/modules'
     _individual_key = None
+    _resource = Processor
+    _module_type = 'PROCESSOR'
 
     def __init__(self, project_id: UUID, session: Session):
         self.project_id = project_id
