@@ -2,8 +2,12 @@
 from typing import Optional, Dict, List, Union, Iterable, Tuple
 from uuid import UUID
 
+from citrine.resources.predictor_evaluation_execution import PredictorEvaluationExecutionCollection
+from citrine.resources.predictor_evaluation_workflow import PredictorEvaluationWorkflowCollection
+from deprecation import deprecated
+
 from citrine._session import Session
-from citrine.resources.ara_definition import AraDefinitionCollection
+from citrine.resources.table_config import TableConfigCollection
 from citrine.resources.descriptors import DescriptorMethods
 from citrine.resources.module import ModuleCollection
 from citrine.resources.design_space import DesignSpaceCollection
@@ -32,7 +36,7 @@ from citrine.resources.ingredient_spec import IngredientSpecCollection
 from citrine._rest.collection import Collection
 from citrine._rest.resource import Resource
 from citrine._serialization import properties
-from citrine.resources.table import TableCollection
+from citrine.resources.gemtables import GemTableCollection
 from citrine.resources.user import User
 
 
@@ -115,15 +119,25 @@ class Project(Resource['Project']):
         """Return a resource representing all visible workflows."""
         return WorkflowCollection(self.uid, self.session)
 
+    @property
+    def predictor_evaluation_workflows(self) -> PredictorEvaluationWorkflowCollection:
+        """[ALPHA] Return a collection representing all visible predictor evaluation workflows."""
+        return PredictorEvaluationWorkflowCollection(self.uid, self.session)
+
+    @property
+    def predictor_evaluation_executions(self) -> PredictorEvaluationExecutionCollection:
+        """[ALPHA] Return a collection representing all visible predictor evaluation executions."""
+        return PredictorEvaluationExecutionCollection(project_id=self.uid, session=self.session)
+
     @property
     def datasets(self) -> DatasetCollection:
         """Return a resource representing all visible datasets."""
         return DatasetCollection(self.uid, self.session)
 
     @property
-    def tables(self) -> TableCollection:
+    def tables(self) -> GemTableCollection:
         """Return a resource representing all visible Tables."""
-        return TableCollection(self.uid, self.session)
+        return GemTableCollection(self.uid, self.session)
 
     @property
     def property_templates(self) -> PropertyTemplateCollection:
@@ -196,9 +210,18 @@ class Project(Resource['Project']):
         return IngredientSpecCollection(self.uid, None, self.session)
 
     @property
-    def ara_definitions(self) -> AraDefinitionCollection:
-        """Return a resource representing all ara definitions in the project."""
-        return AraDefinitionCollection(self.uid, self.session)
+    def table_configs(self) -> TableConfigCollection:
+        """Return a resource representing all Table Configs in the project."""
+        return TableConfigCollection(self.uid, self.session)
+
+    @property
+    @deprecated(deprecated_in="0.52.2", details="Use table_configs instead")
+    def ara_definitions(self) -> TableConfigCollection:  # pragma: no cover
+        """[DEPRECATED] Use table_configs instead."""
+        from warnings import warn
+        warn("ara_definitions is deprecated and will soon be removed. "
+             "Please call table_configs instead.", DeprecationWarning)
+        return self.table_configs
 
     def share(self,
               project_id: str,
@@ -210,6 +233,34 @@ class Project(Resource['Project']):
             "resource": {"type": resource_type, "id": resource_id}
         })
 
+    def transfer_resource(self, resource: Resource,
+                          receiving_project_uid: Union[str, UUID]) -> bool:
+        """
+        Transfer ownership of a resource.
+
+        The new owner of the the supplied resource becomes the project
+        with uid = receiving_project_uid.
+
+        Parameters
+        ----------
+        resource: Resource
+            The resource owned by this project, which will get transferred to
+            the project with uid = receiving_project_uid.
+        receiving_project_uid: Union[string, UUID]
+            The uid of the project to which the resource will be transferred.
+
+        Returns
+        -------
+        bool
+            Returns True upon successful resource transfer.
+
+        """
+        self.session.checked_post(self._path() + "/transfer-resource", {
+            "to_project_id": str(receiving_project_uid),
+            "resource": resource.as_entity_dict()})
+
+        return True
+
     def make_public(self,
                     resource: Resource) -> bool:
         """
@@ -368,8 +419,35 @@ class ProjectCollection(Collection[Project]):
         """
         return super().register(Project(name, description))
 
+    def list(self,
+             page: Optional[int] = None,
+             per_page: int = 1000) -> Iterable[Project]:
+        """
+        List projects using pagination.
+
+        Leaving page and per_page as default values will yield all elements in the
+        collection, paginating over all available pages.
+
+        Parameters
+        ---------
+        page: int, optional
+            The "page" of results to list. Default is to read all pages and yield
+            all results.  This option is deprecated.
+        per_page: int, optional
+            Max number of results to return per page. Default is 1000.  This parameter
+            is used when making requests to the backend service.  If the page parameter
+            is specified it limits the maximum number of elements in the response.
+
+        Returns
+        -------
+        Iterable[Project]
+            Projects in this collection.
+
+        """
+        return super().list(page, per_page)
+
     def search(self, search_params: Optional[dict] = None,
-               per_page: int = 100) -> Iterable[Project]:
+               per_page: int = 1000) -> Iterable[Project]:
         """
         Search for projects matching the desired name or description.
 
@@ -392,16 +470,14 @@ class ProjectCollection(Collection[Project]):
             A dict representing the body of the post request that will be sent to the search
             endpoint to filter the results ie.
             {
-                "search_params": {
-                    "name": {
-                        "value": "Polymer Project",
-                        "search_method": "EXACT"
-                    },
-                    "description": {
-                        "value": "polymer chain length",
-                        "search_method": "SUBSTRING"
-                    },
-                }
+                "name": {
+                    "value": "Polymer Project",
+                    "search_method": "EXACT"
+                },
+                "description": {
+                    "value": "polymer chain length",
+                    "search_method": "SUBSTRING"
+                },
             }
             The dict can constain any combination of (one or all) search specifications for the
             name, description, and status fields of a project. For each parameter specified, the
@@ -454,7 +530,7 @@ class ProjectCollection(Collection[Project]):
             field should be passed as the key for the outermost dict, with its value the request
             body, so that we can easily unpack the keyword argument when it gets passed to
             fetch_func.
-            ie. { 'search_params': {'name': {'value': 'Project', 'search_method': 'SUBSTRING'} } }
+            ie. {'name': {'value': 'Project', 'search_method': 'SUBSTRING'} }
 
         Returns
         -------
@@ -466,7 +542,7 @@ class ProjectCollection(Collection[Project]):
         """
         # Making 'json' the key of the outermost dict, so that search_params can be passed
         # directly to the function making the request with keyword expansion
-        json_body = {} if search_params is None else {'json': search_params}
+        json_body = {} if search_params is None else {'json': {'search_params': search_params}}
 
         path = self._get_path() + "/search"
 
