@@ -2,32 +2,50 @@
 from typing import Optional
 from uuid import UUID
 
-from citrine.informatics.modules import ModuleRef
-from citrine.informatics.scores import Score
 from citrine._rest.collection import Collection
 from citrine._rest.resource import Resource
 from citrine._serialization import properties
 from citrine._session import Session
+from citrine.informatics.modules import ModuleRef
+from citrine.informatics.scores import Score
 
 
 class WorkflowExecution(Resource['WorkflowExecution']):
-    """[ALPHA] A Citrine Workflow Execution."""
+    """[ALPHA] A Citrine Workflow Execution.
+
+    Parameters
+    ----------
+    uid: str
+        Unique identifier of the workflow execution
+    project_id: str
+        Unique identifier of the project that contains the workflow execution
+    workflow_id: str
+        Unique identifier of the workflow that was executed
+    version_number: int
+        Integer identifier that increases each time the workflow is executed.  The first execution
+        has version_number = 1.
+
+    """
 
     _response_key = 'WorkflowExecutions'
 
     uid = properties.UUID('id')
     project_id = properties.UUID('project_id', deserializable=False)
     workflow_id = properties.UUID('workflow_id', deserializable=False)
+    version_number = properties.Integer("version_number")
 
     def __init__(self,
                  uid: Optional[str] = None,
                  project_id: Optional[str] = None,
                  workflow_id: Optional[str] = None,
-                 session: Optional[Session] = None):
+                 session: Optional[Session] = None,
+                 version_number: Optional[int] = None,
+                 ):
         self.uid: str = uid
         self.project_id: str = project_id
         self.workflow_id: str = workflow_id
         self.session: Session = session
+        self.version_number = version_number
 
     def __str__(self):
         return '<WorkflowExecution {!r}>'.format(str(self.uid))
@@ -59,9 +77,10 @@ class WorkflowExecutionCollection(Collection[WorkflowExecution]):
     _collection_key = 'response'
     _resource = WorkflowExecution
 
-    def __init__(self, project_id: UUID, workflow_id: UUID, session: Optional[Session] = None):
+    def __init__(self, project_id: UUID, workflow_id: Optional[UUID],
+                 session: Optional[Session] = None):
         self.project_id: UUID = project_id
-        self.workflow_id: UUID = workflow_id
+        self.workflow_id: Optional[UUID] = workflow_id
         self.session: Optional[Session] = session
 
     def build(self, data: dict) -> WorkflowExecution:
@@ -69,7 +88,8 @@ class WorkflowExecutionCollection(Collection[WorkflowExecution]):
         execution = WorkflowExecution.build(data)
         execution.session = self.session
         execution.project_id = self.project_id
-        execution.workflow_id = self.workflow_id
+        if self.workflow_id is not None:
+            execution.workflow_id = self.workflow_id
         return execution
 
     def trigger(self, execution_input: [Score, ModuleRef]) -> WorkflowExecution:
